@@ -18,13 +18,18 @@ int main (int argc, char **argv)
   Glib::RefPtr<Gtk::Builder> refBuilder = Gtk::Builder::create();
   try
   {
-    refBuilder->add_from_file("basic.ui");
+    refBuilder->add_from_file("basic.glade");
   }
   catch(const Glib::FileError& ex)
   {
     std::cerr << "FileError: " << ex.what() << std::endl;
     return 1;
   }
+  catch(const Glib::MarkupError& ex)
+  {
+    std::cerr << "MarkupError: " << ex.what() << std::endl;
+    return 1;
+  }
   catch(const Gtk::BuilderError& ex)
   {
     std::cerr << "BuilderError: " << ex.what() << std::endl;
@@ -46,5 +51,7 @@ int main (int argc, char **argv)
     kit.run(*pDialog);
   }
 
+  delete pDialog;
+
   return 0;
 }
