@@ -21,22 +21,23 @@
 
 ExampleWindow::ExampleWindow()
 :
-  m_VBox2(false, 20),
-  m_VBox_HScale(false, 10),
-  m_HBox_Scales(false, 10),
-  m_HBox_Digits(false, 10),
-  m_HBox_PageSize(false, 10),
+  m_VBox_Top(Gtk::ORIENTATION_VERTICAL, 0),
+  m_VBox2(Gtk::ORIENTATION_VERTICAL, 20),
+  m_VBox_HScale(Gtk::ORIENTATION_VERTICAL, 10),
+  m_HBox_Scales(Gtk::ORIENTATION_HORIZONTAL, 10),
+  m_HBox_Digits(Gtk::ORIENTATION_HORIZONTAL, 10),
+  m_HBox_PageSize(Gtk::ORIENTATION_HORIZONTAL, 10),
 
   // Value, lower, upper, step_increment, page_increment, page_size:
   // Note that the page_size value only makes a difference for
   // scrollbar widgets, and the highest value you'll get is actually
   // (upper - page_size).
   m_adjustment( Gtk::Adjustment::create(0.0, 0.0, 101.0, 0.1, 1.0, 1.0) ),
-  m_adjustment_digits( Gtk::Adjustment::create(1.0, 0.0, 5.0) ),
+  m_adjustment_digits( Gtk::Adjustment::create(1.0, 0.0, 5.0, 1.0, 2.0) ),
   m_adjustment_pagesize( Gtk::Adjustment::create(1.0, 1.0, 101.0) ),
 
-  m_VScale(m_adjustment),
-  m_HScale(m_adjustment),
+  m_VScale(m_adjustment, Gtk::ORIENTATION_VERTICAL),
+  m_HScale(m_adjustment, Gtk::ORIENTATION_HORIZONTAL),
   m_Scale_Digits(m_adjustment_digits),
   m_Scale_PageSize(m_adjustment_pagesize),
 
@@ -51,19 +52,18 @@ ExampleWindow::ExampleWindow()
   m_Button_Quit("Quit")
 {
   set_title("range controls");
+  set_default_size(300, 350);
 
   //VScale:
-  m_VScale.set_update_policy(Gtk::UPDATE_CONTINUOUS);
   m_VScale.set_digits(1);
   m_VScale.set_value_pos(Gtk::POS_TOP);
   m_VScale.set_draw_value();
+  m_VScale.set_inverted(); // highest value at top
 
   //HScale:
-  m_HScale.set_update_policy(Gtk::UPDATE_CONTINUOUS);
   m_HScale.set_digits(1);
   m_HScale.set_value_pos(Gtk::POS_TOP);
   m_HScale.set_draw_value();
-  m_HScale.set_size_request(200, 30);
 
   add(m_VBox_Top);
   m_VBox_Top.pack_start(m_VBox2);
@@ -77,14 +77,13 @@ ExampleWindow::ExampleWindow()
   m_VBox_HScale.pack_start(m_HScale);
 
   //Scrollbar:
-  m_Scrollbar.set_update_policy(Gtk::UPDATE_CONTINUOUS);
   m_VBox_HScale.pack_start(m_Scrollbar);
 
   //CheckButton:
   m_CheckButton.set_active();
   m_CheckButton.signal_toggled().connect( sigc::mem_fun(*this,
     &ExampleWindow::on_checkbutton_toggled) );
-  m_VBox2.pack_start(m_CheckButton);
+  m_VBox2.pack_start(m_CheckButton, Gtk::PACK_SHRINK);
 
   //Menus:
   Gtk::MenuItem* item = Gtk::manage(new Gtk::MenuItem("Top"));
@@ -111,25 +110,6 @@ ExampleWindow::ExampleWindow()
       &ExampleWindow::on_menu_position), Gtk::POS_RIGHT));
   m_Menu_Position.append(*item);
 
-
-  item = Gtk::manage(new Gtk::MenuItem("Continuous"));
-  item->signal_activate().connect(
-    sigc::bind(sigc::mem_fun(*this,
-      &ExampleWindow::on_menu_policy), Gtk::UPDATE_CONTINUOUS));
-  m_Menu_Policy.append(*item);
-
-  item = Gtk::manage(new Gtk::MenuItem("Discontinuous"));
-  item->signal_activate().connect(
-    sigc::bind(sigc::mem_fun(*this,
-      &ExampleWindow::on_menu_policy), Gtk::UPDATE_DISCONTINUOUS));
-  m_Menu_Policy.append(*item);
-
-  item = Gtk::manage(new Gtk::MenuItem("Delayed"));
-  item->signal_activate().connect(
-    sigc::bind(sigc::mem_fun(*this,
-      &ExampleWindow::on_menu_policy), Gtk::UPDATE_DELAYED));
-  m_Menu_Policy.append(*item);
-
   //Digits:
   m_HBox_Digits.pack_start(
     *Gtk::manage(new Gtk::Label("Scale Digits:", 0)), Gtk::PACK_SHRINK);
@@ -147,8 +127,8 @@ ExampleWindow::ExampleWindow()
     &ExampleWindow::on_adjustment2_value_changed));
   m_HBox_PageSize.pack_start(m_Scale_PageSize);
 
-  m_VBox2.pack_start(m_HBox_Digits);
-  m_VBox2.pack_start(m_HBox_PageSize);
+  m_VBox2.pack_start(m_HBox_Digits, Gtk::PACK_SHRINK);
+  m_VBox2.pack_start(m_HBox_PageSize, Gtk::PACK_SHRINK);
   m_VBox_Top.pack_start(m_Separator, Gtk::PACK_SHRINK);
   m_VBox_Top.pack_start(m_Button_Quit, Gtk::PACK_SHRINK);
 
@@ -177,12 +157,6 @@ void ExampleWindow::on_menu_position(Gtk::PositionType postype)
   m_HScale.set_value_pos(postype);
 }
 
-void ExampleWindow::on_menu_policy(Gtk::UpdateType type)
-{
-  m_VScale.set_update_policy(type);
-  m_HScale.set_update_policy(type);
-}
-
 void ExampleWindow::on_adjustment1_value_changed()
 {
   const double val = m_adjustment_digits->get_value();
